==> hyades.source_3.0.2_20050225_1641.zip: org/eclipse/hyades/trace/ui/internal/launcher/ProfileJavaAppletShortcut.java <==
/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.trace.ui.internal.launcher;

import java.util.List;
import org.eclipse.debug.core.ILaunchConfiguration;
import org.eclipse.debug.core.ILaunchManager;
import org.eclipse.debug.ui.DebugUITools;
import org.eclipse.debug.ui.IDebugModelPresentation;
import org.eclipse.debug.ui.IDebugUIConstants;
import org.eclipse.hyades.trace.ui.UIPlugin;
import org.eclipse.jdt.core.IType;
import org.eclipse.jdt.internal.debug.ui.launcher.JavaAppletLaunchShortcut;
import org.eclipse.jdt.ui.JavaElementLabelProvider;
import org.eclipse.jface.window.Window;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.dialogs.ElementListSelectionDialog;

public class ProfileJavaAppletShortcut extends JavaAppletLaunchShortcut {

	/*
	 * @see org.eclipse.jdt.internal.debug.ui.launcher.JavaApplicationLaunchShortcut#launch(org.eclipse.jdt.core.IType, java.lang.String)
	 */
	protected void launch(IType type, final String mode) {
		final ILaunchConfiguration config = findLaunchConfiguration(type, mode);
		if (config != null) {
			Display.getDefault().asyncExec(new Runnable() {
				public void run() {
					Shell shell = UIPlugin.getActiveWorkbenchShell();
					int result = DebugUITools.openLaunchConfigurationPropertiesDialog(shell, config, IDebugUIConstants.ID_PROFILE_LAUNCH_GROUP);
					if (result == Window.OK) {
						DebugUITools.launch(config, mode);
					}
				}
			});
		}
	}

	/**
	 * Prompts the user to select a type
	 * 
	 * @return the selected type or <code>null</code> if none.
	 */
	protected IType chooseType(IType[] types, String mode) {
		if (mode.equals(ILaunchManager.PROFILE_MODE)) {
			ElementListSelectionDialog dialog= new ElementListSelectionDialog(getShell(), new JavaElementLabelProvider());
			dialog.setElements(types);
			dialog.setTitle(UIPlugin.getResourceString("LAUNCH_SHORTCUT_SELECT_APPLET_TITLE")); //$NON-NLS-1$
			dialog.setMessage(UIPlugin.getResourceString("LAUNCH_SHORTCUT_SELECT_APPLET_MSG"));  //$NON-NLS-1$
			dialog.setMultipleSelection(false);
			if (dialog.open() == Window.OK) {
				return (IType)dialog.getFirstResult();
			}
			return null;
		}
		else {
			return super.chooseType(types, mode);
		}
	}

	/**
	 * Show a selection dialog that allows the user to choose one of the specified
	 * launch configurations.  Return the chosen config, or <code>null</code> if the
	 * user cancelled the dialog.
	 */
	protected ILaunchConfiguration chooseConfiguration(List configList, String mode) {
		if (mode.equals(ILaunchManager.PROFILE_MODE)) {
			IDebugModelPresentation labelProvider = DebugUITools.newDebugModelPresentation();
			ElementListSelectionDialog dialog= new ElementListSelectionDialog(getShell(), labelProvider);
			dialog.setElements(configList.toArray());
			dialog.setTitle(UIPlugin.getResourceString("LAUNCH_SHORTCUT_SELECT_CONF_TITLE"));  //$NON-NLS-1$
			dialog.setMessage(UIPlugin.getResourceString("LAUNCH_SHORTCUT_SELECT_CONF_MSG"));  //$NON-NLS-1$
			dialog.setMultipleSelection(false);
			int result= dialog.open();
			labelProvider.dispose();
			if (result == Window.OK) {
				return (ILaunchConfiguration)dialog.getFirstResult();
			}
			return null;
		}
		else {
			return super.chooseConfiguration(configList, mode);
		}
	}
}

==> hyades.source_3.3.0_20050623_2150.zip: org/eclipse/hyades/trace/ui/internal/launcher/ProfileJavaAppletShortcut.java <==
/**********************************************************************
 * Copyright (c) 2005 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * $Id: ProfileJavaAppletShortcut.java,v 1.6 2005/02/16 22:24:01 qiyanli Exp $
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.trace.ui.internal.launcher;

import java.util.List;

import org.eclipse.core.runtime.Status;
import org.eclipse.debug.core.ILaunchConfiguration;
import org.eclipse.debug.core.ILaunchManager;
import org.eclipse.debug.ui.DebugUITools;
import org.eclipse.debug.ui.IDebugModelPresentation;
import org.eclipse.debug.ui.IDebugUIConstants;
import org.eclipse.hyades.trace.ui.UIPlugin;
import org.eclipse.jdt.core.IType;
import org.eclipse.jdt.internal.debug.ui.launcher.JavaAppletLaunchShortcut;
import org.eclipse.jdt.ui.JavaElementLabelProvider;
import org.eclipse.jface.window.Window;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.dialogs.ElementListSelectionDialog;

public class ProfileJavaAppletShortcut extends JavaAppletLaunchShortcut {

	/*
	 * @see org.eclipse.jdt.internal.debug.ui.launcher.JavaApplicationLaunchShortcut#launch(org.eclipse.jdt.core.IType, java.lang.String)
	 */
	protected void launch(IType type, final String mode) {
		final ILaunchConfiguration config = findLaunchConfiguration(type, mode);
		if (config != null) {
			Display.getDefault().asyncExec(new Runnable() {
				public void run() {
					Shell shell = UIPlugin.getActiveWorkbenchShell();
					int result = DebugUITools.openLaunchConfigurationPropertiesDialog(shell, config, IDebugUIConstants.ID_PROFILE_LAUNCH_GROUP, new Status(Status.OK, UIPlugin.getPluginId(), RunLaunchProfileStatusHandler.CODE, "", null));
					if (result == Window.OK) {
						DebugUITools.launch(config, mode);
					}
				}
			});
		}
	}

	/**
	 * Prompts the user to select a type
	 * 
	 * @return the selected type or <code>null</code> if none.
	 */
	protected IType chooseType(IType[] types, String mode) {
		if (mode.equals(ILaunchManager.PROFILE_MODE)) {
			ElementListSelectionDialog dialog= new ElementListSelectionDialog(getShell(), new JavaElementLabelProvider());
			dialog.setElements(types);
			dialog.setTitle(UIPlugin.getResourceString("LAUNCH_SHORTCUT_SELECT_APPLET_TITLE")); //$NON-NLS-1$
			dialog.setMessage(UIPlugin.getResourceString("LAUNCH_SHORTCUT_SELECT_APPLET_MSG"));  //$NON-NLS-1$
			dialog.setMultipleSelection(false);
			if (dialog.open() == Window.OK) {
				return (IType)dialog.getFirstResult();
			}
			return null;
		}
		else {
			return super.chooseType(types, mode);
		}
	}

	/**
	 * Show a selection dialog that allows the user to choose one of the specified
	 * launch configurations.  Return the chosen config, or <code>null</code> if the
	 * user cancelled the dialog.
	 */
	protected ILaunchConfiguration chooseConfiguration(List configList, String mode) {
		if (mode.equals(ILaunchManager.PROFILE_MODE)) {
			IDebugModelPresentation labelProvider = DebugUITools.newDebugModelPresentation();
			ElementListSelectionDialog dialog= new ElementListSelectionDialog(getShell(), labelProvider);
			dialog.setElements(configList.toArray());
			dialog.setTitle(UIPlugin.getResourceString("LAUNCH_SHORTCUT_SELECT_CONF_TITLE"));  //$NON-NLS-1$
			dialog.setMessage(UIPlugin.getResourceString("LAUNCH_SHORTCUT_SELECT_CONF_MSG"));  //$NON-NLS-1$
			dialog.setMultipleSelection(false);
			int result= dialog.open();
			labelProvider.dispose();
			if (result == Window.OK) {
				return (ILaunchConfiguration)dialog.getFirstResult();
			}
			return null;
		}
		else {
			return super.chooseConfiguration(configList, mode);
		}
	}
}
